@@ -1,4 +1,15 @@
+#[cfg(feature = "postgres")]
+pub mod bind_pg;
+#[cfg(feature = "mysql")]
+pub mod bind_mysql;
+#[cfg(feature = "sqlite")]
+pub mod bind_sqlite;
+#[cfg(feature = "mssql")]
+pub mod bind_mssql;
+
+
 use std::time::Duration;
+use bson::Bson;
 
 use chrono::NaiveDateTime;
 use serde::de::DeserializeOwned;
@@ -9,10 +20,12 @@ pub use db_adapter::{
 };
 use py_sql::StringConvert;
 use crate::convert::StmtConvert;
+use crate::db::db_adapter::DataDecoder;
 
 pub mod db_adapter;
 
-#[derive(Debug, Clone, Copy)]
+
+#[derive(Debug)]
 pub struct DBPoolOptions {
     pub max_connections: u32,
     pub min_connections: u32,
@@ -20,6 +33,7 @@ pub struct DBPoolOptions {
     pub max_lifetime: Option<Duration>,
     pub idle_timeout: Option<Duration>,
     pub test_before_acquire: bool,
+    pub decoder: Box<dyn DataDecoder>,
 }
 
 impl Default for DBPoolOptions {
@@ -39,6 +53,7 @@ impl Default for DBPoolOptions {
             idle_timeout: None,
             // If true, test the health of a connection on acquire
             test_before_acquire: true,
+            decoder: Box::new(DefaultDecoder {}),
         }
     }
 }
@@ -49,6 +64,16 @@ impl DBPoolOptions {
     }
 }
 
+#[derive(Clone, Debug)]
+pub struct DefaultDecoder {}
+
+impl DataDecoder for DefaultDecoder {
+    fn decode(&self, key: &str, data: &mut Bson) -> crate::Result<()> {
+        return Ok(());
+    }
+}
+
+
 #[derive(Serialize, Deserialize, Debug, Clone, Copy, Eq, PartialEq)]
 pub enum DriverType {
     None = 0,
@@ -61,7 +86,7 @@ pub enum DriverType {
 impl DriverType {
     pub fn is_number_type(&self) -> bool {
         match self {
-            DriverType::Postgres => {
+            DriverType::Postgres|DriverType::Mssql => {
                 return true;
             }
             _ => {
